# Generated by Django 5.1.7 on 2025-03-21 14:36
from __future__ import annotations

import django.db.models.deletion
from django.db import migrations
from django.db import models


class Migration(migrations.Migration):
    dependencies = [
        ("afip", "0015_alter_taxpayer_logo"),
    ]

    operations = [
        migrations.CreateModel(
            name="ClientVatCondition",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("code", models.CharField(max_length=3, verbose_name="code")),
                (
                    "description",
                    models.CharField(max_length=250, verbose_name="description"),
                ),
                (
                    "cmp_clase",
                    models.CharField(
                        help_text="The class of the client VAT condition.",
                        max_length=10,
                        verbose_name="cmp clase",
                    ),
                ),
            ],
            options={
                "verbose_name": "client VAT condition",
                "verbose_name_plural": "client VAT conditions",
            },
        ),
        migrations.AddField(
            model_name="receipt",
            name="client_vat_condition",
            field=models.ForeignKey(
                blank=True,
                help_text="The client VAT condition of the recipient of this receipt.",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="afip.clientvatcondition",
                verbose_name="client VAT condition",
            ),
        ),
    ]
